/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	// Theme prefix.
	var prefix = "magnow-";

	/**
	 * Content color
	 */
	wp.customize( prefix + "content-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ffffff';
			$( '.site-main' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "content-border-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#e9e9e9';
			$( '.site-main' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "content-text-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#666666';
			$( 'article .entry-content, article .entry-summary, article blockquote' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "content-heading-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#666666';
			$( 'article .entry-content h1, article .entry-content h2, article .entry-content h3, article .entry-content h4, article .entry-content h5, article .entry-content h6, article .entry-title' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "content-link-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#0099e6';
			$( 'article .entry-content a, article .entry-content a:link' ).css('color', to);
		} );
	} );

	/**
	 * Header color
	 */
	wp.customize( "blogname", function( value ) {
		value.bind( function( to ) {
			$( ".site-title a" ).text( to );
		} );
	} );

	wp.customize( prefix + "header-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ffffff';
			$( '#masthead' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "site-title-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#323232';
			$( '#masthead .site-title a' ).css('color', to);
		} );
	} );

	/**
	 * Menu color
	 */
	wp.customize( prefix + "menu-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#141414';
			$( '#primary-bar, .slicknav_menu' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "menu-border-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#343434';
			$( '#primary-bar, #primary-nav .home_item, #primary-nav ul li, .nav-right' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "menu-link-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ffffff';
			$( '#primary-nav ul li a' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "menu-link-login-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#999999';
			$( '#primary-nav ul.nav-right li a, #primary-nav ul.nav-right .fa' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "text-login", function( value ) {
		value.bind( function( to ) {
			$( ".login-text" ).text( to );
		} );
	} );

	/**
	 * Sidebar color
	 */
	wp.customize( prefix + "sidebar-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ffffff';
			$( '.sidebar' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "sidebar-border-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#e9e9e9';
			$( '.sidebar, .widget .widget-title, .widget ul > li' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "footer-text-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#666666';
			$( '.sidebar .widget' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "footer-text-title-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#333333';
			$( '.sidebar .widget .widget-title' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "footer-link-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#666666';
			$( '.sidebar .widget a' ).css('color', to);
		} );
	} );

	/**
	 * Footer color
	 */
	wp.customize( prefix + "footer-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#141414';
			$( '#footer' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "footer-border-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#343434';
			$( '.footer-columns .container, .widget ul > li, #site-bottom .footer-links ul li' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "footer-text-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#999999';
			$( '#footer .widget, #site-bottom .copyright' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "footer-text-title-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ffffff';
			$( '#footer .widget .widget-title' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "footer-link-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#999999';
			$( '#footer a' ).css('color', to);
		} );
	} );

	/**
	 * Site bottom color
	 */
	wp.customize( prefix + "bottom-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ffffff';
			$( '#site-bottom' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "bottom-border-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#e6e6e6';
			$( '#site-bottom .footer-links ul li' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "bottom-text-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#666666';
			$( '#site-bottom' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "bottom-link-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#666666';
			$( '#site-bottom a' ).css('color', to);
		} );
	} );

} )( jQuery );
