<?php
/**
 * Content color
 *
 * @package    MagNow
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'magnow_customizer_content_styles' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0
 */
function magnow_customizer_content_styles() {

	// Theme prefix
	$prefix = 'magnow-';
	
	// Content Background Color
	$content_bg = magnow_mod( $prefix . 'content-color' );

	if ( $content_bg !== customizer_library_get_default( $prefix . 'content-color' ) ) {

		$color = sanitize_hex_color( $content_bg );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-main'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}

	// Content Border Color
	$content_border = magnow_mod( $prefix . 'content-border-color' );

	if ( $content_border !== customizer_library_get_default( $prefix . 'content-border-color' ) ) {

		$color = sanitize_hex_color( $content_border );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-main'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

	// Content text color
	$text_color = magnow_mod( $prefix . 'content-text-color' );

	if ( $text_color !== customizer_library_get_default( $prefix . 'content-text-color' ) ) {

		$color = sanitize_hex_color( $text_color );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'article .entry-content',
				'article .entry-summary',
				'article blockquote',
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Content heading color
	$heading_color = magnow_mod( $prefix . 'content-heading-color' );

	if ( $heading_color !== customizer_library_get_default( $prefix . 'content-heading-color' ) ) {

		$color = sanitize_hex_color( $heading_color );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'article .entry-content h1',
				'article .entry-content h2',
				'article .entry-content h3',
				'article .entry-content h4',
				'article .entry-content h5',
				'article .entry-content h6',
				'.single .hentry h1.entry-title'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Content link color
	$content_link = magnow_mod( $prefix . 'content-link-color' );

	if ( $content_link !== customizer_library_get_default( $prefix . 'content-link-color' ) ) {

		$color = sanitize_hex_color( $content_link );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'article .entry-content a',
				'article .entry-content a:link'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Content link hover color
	$content_link_hover = magnow_mod( $prefix . 'content-link-hover-color' );

	if ( $content_link_hover !== customizer_library_get_default( $prefix . 'content-link-hover-color' ) ) {

		$color = sanitize_hex_color( $content_link_hover );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'article .entry-content a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	} else {
		$color = sanitize_hex_color( $content_link_hover );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'article .entry-content a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

}
endif;
add_action( 'magnow_customizer_library_styles', 'magnow_customizer_content_styles' );