<?php
/**
 * Footer color
 *
 * @package    MagNow
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'magnow_customizer_footer_styles' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0
 */
function magnow_customizer_footer_styles() {

	// Theme prefix
	$prefix = 'magnow-';
	
	// Footer Background Color
	$footer_bg = magnow_mod( $prefix . 'footer-color' );

	if ( $footer_bg !== customizer_library_get_default( $prefix . 'footer-color' ) ) {

		$color = sanitize_hex_color( $footer_bg );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#footer'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}

	// Footer Border Color
	$footer_border = magnow_mod( $prefix . 'footer-border-color' );

	if ( $footer_border !== customizer_library_get_default( $prefix . 'footer-border-color' ) ) {

		$color = sanitize_hex_color( $footer_border );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.footer-columns .container',
				'.footer-columns .widget ul > li',
				'#site-bottom .footer-links ul li'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

	// Footer text color
	$footer_text = magnow_mod( $prefix . 'footer-text-color' );

	if ( $footer_text !== customizer_library_get_default( $prefix . 'footer-text-color' ) ) {

		$color = sanitize_hex_color( $footer_text );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#footer .widget',
				'#footer .widget_posts_thumbnail .entry-meta',
				'#site-bottom .copyright'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Footer text title color
	$footer_text_title = magnow_mod( $prefix . 'footer-text-title-color' );

	if ( $footer_text_title !== customizer_library_get_default( $prefix . 'footer-text-title-color' ) ) {

		$color = sanitize_hex_color( $footer_text_title );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#footer .widget .widget-title'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Footer link color
	$footer_link = magnow_mod( $prefix . 'footer-link-color' );

	if ( $footer_link !== customizer_library_get_default( $prefix . 'footer-link-color' ) ) {

		$color = sanitize_hex_color( $footer_link );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#footer a:link',
				'#footer a:visited',
				'#footer .widget a:link', 
				'#footer .widget a:visited',
				'#site-bottom a:link'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Footer link hover color
	$footer_link_hover = magnow_mod( $prefix . 'footer-link-hover-color' );

	if ( $footer_link_hover !== customizer_library_get_default( $prefix . 'footer-link-hover-color' ) ) {

		$color = sanitize_hex_color( $footer_link_hover );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#footer .widget ul li a:hover',
				'#footer .widget a:hover',
				'#footer a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	} else {
		$color = sanitize_hex_color( $footer_link_hover );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#footer a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

}
endif;
add_action( 'magnow_customizer_library_styles', 'magnow_customizer_footer_styles' );