<?php
/**
 * Sidebar color
 *
 * @package    MagNow
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'magnow_customizer_sidebar_styles' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0
 */
function magnow_customizer_sidebar_styles() {

	// Theme prefix
	$prefix = 'magnow-';
	
	// Sidebar Background Color
	$sidebar_bg = magnow_mod( $prefix . 'sidebar-color' );

	if ( $sidebar_bg !== customizer_library_get_default( $prefix . 'sidebar-color' ) ) {

		$color = sanitize_hex_color( $sidebar_bg );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.sidebar'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}

	// Sidebar Border Color
	$sidebar_border = magnow_mod( $prefix . 'sidebar-border-color' );

	if ( $sidebar_border !== customizer_library_get_default( $prefix . 'sidebar-border-color' ) ) {

		$color = sanitize_hex_color( $sidebar_border );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.sidebar',
				'.sidebar .widget .widget-title',
				'.sidebar .widget ul > li'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

	// Sidebar text color
	$sidebar_text = magnow_mod( $prefix . 'sidebar-text-color' );

	if ( $sidebar_text !== customizer_library_get_default( $prefix . 'sidebar-text-color' ) ) {

		$color = sanitize_hex_color( $sidebar_text );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.sidebar .widget'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Sidebar text title color
	$sidebar_text_title = magnow_mod( $prefix . 'sidebar-text-title-color' );

	if ( $sidebar_text_title !== customizer_library_get_default( $prefix . 'sidebar-text-title-color' ) ) {

		$color = sanitize_hex_color( $sidebar_text_title );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.sidebar .widget .widget-title'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Sidebar link color
	$sidebar_link = magnow_mod( $prefix . 'sidebar-link-color' );

	if ( $sidebar_link !== customizer_library_get_default( $prefix . 'sidebar-link-color' ) ) {

		$color = sanitize_hex_color( $sidebar_link );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.sidebar .widget a'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Sidebar link hover color
	$sidebar_link_hover = magnow_mod( $prefix . 'sidebar-link-hover-color' );

	if ( $sidebar_link_hover !== customizer_library_get_default( $prefix . 'sidebar-link-hover-color' ) ) {

		$color = sanitize_hex_color( $sidebar_link_hover );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.sidebar .widget a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	} else {
		$color = sanitize_hex_color( $sidebar_link_hover );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.sidebar .widget a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

}
endif;
add_action( 'magnow_customizer_library_styles', 'magnow_customizer_sidebar_styles' );