<?php
/**
 * Two Columns widget.
 *
 * @package    MagNow
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class MagNow_Two_Columns_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-magnow-home-two-columns',
			'description' => __( 'Widget to display two columns custom posts list in two columns. Please only use it on home page/home sidebar.', 'magnow' )
		);

		// Create the widget.
		parent::__construct(
			'magnow-home-two-columns',         // $this->id_base
			__( 'Home Two Column', 'magnow' ), // $this->name
			$widget_options                    // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			echo '<div class="listing-2-col clearfix">';

				// Column first post
				magnow_home_posts_first( $args, $instance );

				// Column first post
				magnow_home_posts_second( $args, $instance );

			echo '</div>';

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['limit']   = (int) $new_instance['limit'];
		$instance['cat']     = $new_instance['cat'];
		$instance['limit_2'] = (int) $new_instance['limit_2'];
		$instance['cat_2']   = $new_instance['cat_2'];

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'limit'   => 4,
			'cat'     => '',
			'limit_2' => 4,
			'cat_2'   => ''
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<h3><?php _e( 'Posts column first', 'magnow' ); ?></h3>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>">
				<?php _e( 'Number of posts to show', 'magnow' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" step="1" min="0" value="<?php echo (int)( $instance['limit'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Choose Category', 'magnow' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<option value="0"><?php _e( 'All categories &hellip;', 'magnow' ); ?></option>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo esc_attr( $category->term_id ); ?>" <?php selected( $instance['cat'], $category->term_id ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

		<hr />

		<h3><?php _e( 'Posts column second', 'magnow' ); ?></h3>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit_2' ); ?>">
				<?php _e( 'Number of posts to show', 'magnow' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit_2' ); ?>" name="<?php echo $this->get_field_name( 'limit_2' ); ?>" type="number" step="1" min="0" value="<?php echo (int)( $instance['limit_2'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat_2' ); ?>"><?php _e( 'Choose Category', 'magnow' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat_2' ); ?>" name="<?php echo $this->get_field_name( 'cat_2' ); ?>" style="width:100%;">
				<?php $categories_2 = get_terms( 'category' ); ?>
				<option value="0"><?php _e( 'All categories &hellip;', 'magnow' ); ?></option>
				<?php foreach( $categories_2 as $category_2 ) { ?>
					<option value="<?php echo esc_attr( $category_2->term_id ); ?>" <?php selected( $instance['cat_2'], $category_2->term_id ); ?>><?php echo esc_html( $category_2->name ); ?></option>
				<?php } ?>
			</select>
		</p>

	<?php

	}

}

/**
 * Column first posts
 */
function magnow_home_posts_first( $args, $instance ) {

	// Theme prefix
	$prefix = 'magnow-';

	// Pull the selected category.
	$cat_id = isset( $instance['cat'] ) ? absint( $instance['cat'] ) : 0;

	// Get the category.
	$category = get_category( $cat_id );

	// Get the category archive link.
	$cat_link = get_category_link( $cat_id );

	// Posts query arguments.
	$args = array(
		'post_type'      => 'post',
		'posts_per_page' => ( ! empty( $instance['limit'] ) ) ? absint( $instance['limit'] ) : 4
	);

	// Limit to category based on user selected tag.
	if ( ! $cat_id == 0 ) {
		$args['cat'] = $cat_id;
	}

	// Allow dev to filter the post arguments.
	$query = apply_filters( 'magnow_home_two_columns_1_args', $args );

	// The post query.
	$posts = new WP_Query( $query );

	if ( $posts->have_posts() ) : ?>

		<div class="box left">

			<?php
				if ( $cat_id == 0 ) {
					echo '<h3 class="category-title bg1">' . __( 'Latest Articles', 'magnow' ) . '</h3>';
				} else {
					echo '<h3 class="category-title category-id-' . $category->term_id . '"><a href="' . esc_url( $cat_link ) . '">' . esc_attr( $category->name ) . '</a></h3>';
				}
			?>

			<ul>
				<?php $i = 0; ?>
				<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
					<?php if ( $i++ == 0 ) { ?>
						<li class="primary">
							<a class="post-link" href="<?php the_permalink(); ?>">
								<span class="gradient"></span>
								<?php the_post_thumbnail( 'medium', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php the_title( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '>', '</h2>' ); ?>
							</a>
						</li>
					<?php } elseif ( $i++ == 2 ) { ?>
						<li class="secondary clearfix">
							<a href="<?php the_permalink(); ?>">
								<?php the_post_thumbnail( 'magnow-home-thumb-3', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php the_title( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '>', '</h2>' ); ?>
								<div class="entry-meta"><?php printf( __( '%s ago', 'magnow' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) ); ?></div>
							</a>
						</li>
					<?php } else { ?>
						<li class="list">
							<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
						</li>
					<?php } ?>
				<?php endwhile; ?>
			</ul>

		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();
}

/**
 * Column second posts
 */
function magnow_home_posts_second( $args, $instance ) {

	// Theme prefix
	$prefix = 'magnow-';

	// Pull the selected category.
	$cat_id = isset( $instance['cat_2'] ) ? absint( $instance['cat_2'] ) : 0;

	// Get the category.
	$category = get_category( $cat_id );

	// Get the category archive link.
	$cat_link = get_category_link( $cat_id );

	// Posts query arguments.
	$args = array(
		'post_type'      => 'post',
		'posts_per_page' => ( ! empty( $instance['limit_2'] ) ) ? absint( $instance['limit_2'] ) : 4
	);

	// Limit to category based on user selected tag.
	if ( ! $cat_id == 0 ) {
		$args['cat'] = $cat_id;
	}

	// Allow dev to filter the post arguments.
	$query = apply_filters( 'magnow_home_two_columns_2_args', $args );

	// The post query.
	$posts = new WP_Query( $query );

	if ( $posts->have_posts() ) : ?>

		<div class="box right">

			<?php
				if ( $cat_id == 0 ) {
					echo '<h3 class="category-title bg1">' . __( 'Latest Articles', 'magnow' ) . '</h3>';
				} else {
					echo '<h3 class="category-title category-id-' . $category->term_id . '"><a href="' . esc_url( $cat_link ) . '">' . esc_attr( $category->name ) . '</a></h3>';
				}
			?>

			<ul>
				<?php $i = 0; ?>
				<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
					<?php if ( $i++ == 0 ) { ?>
						<li class="primary">
							<a class="post-link" href="<?php the_permalink(); ?>">
								<span class="gradient"></span>
								<?php the_post_thumbnail( 'medium', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php the_title( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '>', '</h2>' ); ?>
							</a>
						</li>
					<?php } elseif ( $i++ == 2 ) { ?>
						<li class="secondary clearfix">
							<a href="<?php the_permalink(); ?>">
								<?php the_post_thumbnail( 'magnow-home-thumb-3', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php the_title( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '>', '</h2>' ); ?>
								<div class="entry-meta"><?php printf( __( '%s ago', 'magnow' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) ); ?></div>
							</a>
						</li>
					<?php } else { ?>
						<li class="list">
							<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
						</li>
					<?php } ?>
				<?php endwhile; ?>
			</ul>

		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();
}